<?php

declare(strict_types=1);

namespace Dedi\SyliusMigrationPlugin\Registry;

use Dedi\SyliusMigrationPlugin\Service\MigrationAction\MigrationActionInterface;

class MigrationActionRegistry
{
    private array $migrationActions = [];

    public function getMigrationActions(): array
    {
        return $this->migrationActions;
    }

    public function addMigrationAction(MigrationActionInterface $migrationAction): array
    {
        if (!$this->hasMigrationAction($migrationAction->getType())) {
            $this->migrationActions[$migrationAction->getType()] = $migrationAction;
        }

        return $this->migrationActions;
    }

    public function getMigrationAction(string $type): MigrationActionInterface
    {
        if (!$this->hasMigrationAction($type)) {
            throw new \LogicException(sprintf('MigrationAction %s not registered', $type));
        }

        return $this->migrationActions[$type];
    }

    public function hasMigrationAction(string $type): bool
    {
        return array_key_exists($type, $this->migrationActions);
    }
}
